@@ -56,58 +56,55 @@ void bli_init_auto( void )
 
 void bli_finalize_auto( void )
 {
-#ifdef BLIS_ENABLE_STAY_AUTO_INITIALIZED
-
-	// If BLIS was configured to stay initialized after being automatically
-	// initialized, we honor the configuration request and do nothing.
-	// BLIS will remain initialized unless and until the user explicitly
-	// calls bli_finalize().
-
-#else
-
-	bli_finalize_once();
-
-#endif
+	// The _auto() functions are used when initializing the BLAS compatibility
+	// layer. It would not make much sense to automatically initialize and
+	// finalize for every BLAS routine call; therefore, we remain initialized
+	// unless and until the application explicitly calls bli_finalize().
 }
 
 // -----------------------------------------------------------------------------
 
-void bli_init_apis( void )
-{
-	// Initialize various sub-APIs.
-	bli_gks_init();
-	bli_ind_init();
-	bli_thread_init();
-	bli_pack_init();
-	bli_memsys_init();
-}
-
-void bli_finalize_apis( void )
-{
-	// Finalize various sub-APIs.
-	bli_memsys_finalize();
-	bli_pack_finalize();
-	bli_thread_finalize();
-	bli_ind_finalize();
-	bli_gks_finalize();
-}
-
-// -----------------------------------------------------------------------------
-
-// A pthread_once_t variable is a pthread structure used in pthread_once().
-// pthread_once() is guaranteed to execute exactly once among all threads that
-// pass in this control object. Thus, we need one for initialization and a
-// separate one for finalization.
-static bli_pthread_once_t once_init     = BLIS_PTHREAD_ONCE_INIT;
-static bli_pthread_once_t once_finalize = BLIS_PTHREAD_ONCE_INIT;
-
 void bli_init_once( void )
 {
-	bli_pthread_once( &once_init, bli_init_apis );
+	bli_init_apis();
 }
 
 void bli_finalize_once( void )
 {
-	bli_pthread_once( &once_finalize, bli_finalize_apis );
+	bli_finalize_apis();
+}
+
+// -----------------------------------------------------------------------------
+
+static bli_pthread_switch_t gks_g_state    = BLIS_PTHREAD_SWITCH_INIT;
+static BLIS_THREAD_LOCAL
+       bli_pthread_switch_t ind_l_state    = BLIS_PTHREAD_SWITCH_INIT;
+static bli_pthread_switch_t thread_g_state = BLIS_PTHREAD_SWITCH_INIT;
+static BLIS_THREAD_LOCAL
+       bli_pthread_switch_t rntm_l_state   = BLIS_PTHREAD_SWITCH_INIT;
+static bli_pthread_switch_t memsys_g_state = BLIS_PTHREAD_SWITCH_INIT;
+
+int bli_init_apis( void )
+{
+	// Initialize various sub-APIs.
+	bli_pthread_switch_on( &gks_g_state,    bli_gks_init );
+	bli_pthread_switch_on( &ind_l_state,    bli_ind_init );
+	bli_pthread_switch_on( &thread_g_state, bli_thread_init );
+	bli_pthread_switch_on( &rntm_l_state,   bli_rntm_init );
+	bli_pthread_switch_on( &memsys_g_state, bli_memsys_init );
+
+	return 0;
+}
+
+int bli_finalize_apis( void )
+{
+	// Finalize various sub-APIs.
+	bli_pthread_switch_off( &memsys_g_state, bli_memsys_finalize );
+	bli_pthread_switch_off( &rntm_l_state,   bli_rntm_finalize );
+	bli_pthread_switch_off( &thread_g_state, bli_thread_finalize );
+	bli_pthread_switch_off( &ind_l_state,    bli_ind_finalize );
+	bli_pthread_switch_off( &gks_g_state,    bli_gks_finalize );
+
+	return 0;
 }
 
